@@ -43,7 +43,7 @@ class Command(SyncCommon):
         verbosity = int(self.options.get('verbosity'))
         for app_model in get_apps():
             app_name = app_model.__name__.replace('.models', '')
-            if hasattr(app_model, 'models') and app_name in included_apps:
+            if app_name in included_apps:
                 for model in get_models(app_model, include_auto_created=True):
                     model._meta.managed = model._meta.was_managed
                     if model._meta.managed and verbosity >= 3:
